@@ -133,48 +133,50 @@ class BoletoPDF:
         self.pdfCanvas.saveState();
         self.pdfCanvas.translate( x, y );
 
-        linhaInicial = 16
+        linhaInicial = 15
 
         # Horizontal Lines
         self.pdfCanvas.setLineWidth(1)
         self.__horizontalLine( 0, 
-            linhaInicial * self.heightLine, self.width )
+            (linhaInicial + 0) * self.heightLine, self.width )
         self.__horizontalLine( 0, 
             (linhaInicial + 1) * self.heightLine, self.width )
+        self.__horizontalLine( 0, 
+            (linhaInicial + 2) * self.heightLine, self.width )
 
         self.pdfCanvas.setLineWidth(2)
         self.__horizontalLine( 0, 
-            (linhaInicial + 2) * self.heightLine, self.width )
+            (linhaInicial + 3) * self.heightLine, self.width )
 
         # Vertical Lines
         self.pdfCanvas.setLineWidth(1)
         self.__verticalLine( 
-            self.width - (35*mm), 
+            self.width - (30*mm), 
             (linhaInicial + 0) * self.heightLine, 
+            3 * self.heightLine 
+        )
+        self.__verticalLine( 
+            self.width - (30*mm) - (35*mm), 
+            (linhaInicial + 1) * self.heightLine, 
             2 * self.heightLine 
         )
         self.__verticalLine( 
-            self.width - (35*mm) - (30*mm), 
-            (linhaInicial + 0) * self.heightLine, 
-            2 * self.heightLine 
-        )
-        self.__verticalLine( 
-            self.width - (35*mm) - (30*mm) - (40*mm), 
-            (linhaInicial + 0) * self.heightLine, 
+            self.width - (30*mm) - (35*mm) - (40*mm), 
+            (linhaInicial + 1) * self.heightLine, 
             2 * self.heightLine 
         )
 
         # Head
         self.pdfCanvas.setLineWidth(2)
         self.__verticalLine( 40*mm, 
-            (linhaInicial + 2) * self.heightLine, self.heightLine )
+            (linhaInicial + 3) * self.heightLine, self.heightLine )
         self.__verticalLine( 60*mm, 
-            (linhaInicial + 2) * self.heightLine, self.heightLine )
+            (linhaInicial + 3) * self.heightLine, self.heightLine )
 
         if boletoDados.logo_image_path:
             self.pdfCanvas.drawImage( 
                 boletoDados.logo_image_path, 
-                0, (linhaInicial + 2) * self.heightLine + 3, 
+                0, (linhaInicial + 3) * self.heightLine + 3, 
                 40*mm, 
                 self.heightLine, 
                 preserveAspectRatio=True, 
@@ -183,13 +185,13 @@ class BoletoPDF:
         self.pdfCanvas.setFont( 'Helvetica-Bold', 18 )
         self.pdfCanvas.drawCentredString( 
             50*mm, 
-            (linhaInicial + 2) * self.heightLine + 3, 
+            (linhaInicial + 3) * self.heightLine + 3, 
             boletoDados.codigo_dv_banco 
         )
-        self.pdfCanvas.setFont( 'Helvetica-Bold', 10 )
+        self.pdfCanvas.setFont( 'Helvetica-Bold', 11.5 )
         self.pdfCanvas.drawRightString( 
             self.width, 
-            (linhaInicial + 2) * self.heightLine + 3, 
+            (linhaInicial + 3) * self.heightLine + 3, 
             'Recibo do Sacado' 
         )
 
@@ -205,49 +207,60 @@ class BoletoPDF:
 
         self.pdfCanvas.drawString( 
             0, 
-            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
+            (((linhaInicial + 2)*self.heightLine)) + self.deltaTitle, 
             'Cedente' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) - (40*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
+            self.width - (30*mm) - (35*mm) - (40*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.deltaTitle, 
             'Agência/Código Cedente' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
-            'Data Documento' 
+            self.width - (30*mm) - (35*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.deltaTitle, 
+            'CPF/CNPJ Cedente' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
+            self.width - (30*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.deltaTitle, 
             'Vencimento' 
         )
 
         self.pdfCanvas.drawString( 
             0, 
-            (((linhaInicial + 0)*self.heightLine)) + self.deltaTitle, 
+            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
             'Sacado' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) - (40*mm) + self.space, 
-            (((linhaInicial + 0)*self.heightLine)) + self.deltaTitle, 
+            self.width - (30*mm) - (35*mm) - (40*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
             'Nosso Número' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) + self.space, 
-            (((linhaInicial + 0)*self.heightLine)) + self.deltaTitle, 
+            self.width - (30*mm) - (35*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
             'N. do documento' 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) + self.space, 
+            self.width - (30*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.deltaTitle, 
+            'Data Documento' 
+        )
+
+        self.pdfCanvas.drawString( 
+            0, 
+            (((linhaInicial + 0)*self.heightLine)) + self.deltaTitle, 
+            'Endereço Cedente' 
+        )
+        self.pdfCanvas.drawString( 
+            self.width - (30*mm) + self.space, 
             (((linhaInicial + 0)*self.heightLine)) + self.deltaTitle, 
             'Valor Documento' 
         )
 
         self.pdfCanvas.drawString( 
             0, 
-            (((linhaInicial - 1)*self.heightLine-3*cm)) + self.deltaTitle, 
+            (((linhaInicial + 0)*self.heightLine-3*cm)) + self.deltaTitle, 
             'Demonstrativo' 
         )
 
@@ -257,25 +270,46 @@ class BoletoPDF:
 
         self.pdfCanvas.drawString( 
             0 + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.space, 
             boletoDados.cedente 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) - (40*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.space, 
+            self.width - (30*mm) - (35*mm) - (40*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.space, 
             boletoDados.agencia_conta_cedente 
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.space,  
-            boletoDados.data_documento.strftime('%d/%m/%Y') 
+            self.width - (30*mm) - (35*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.space,  
+            boletoDados.cedente_documento
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) + self.space, 
-            (((linhaInicial + 1)*self.heightLine)) + self.space,  
+            self.width - (30*mm) + self.space, 
+            (((linhaInicial + 2)*self.heightLine)) + self.space,  
             boletoDados.data_vencimento.strftime('%d/%m/%Y') 
         )
 
+        self.pdfCanvas.drawString( 
+            0 + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.space, 
+            boletoDados.sacado[0] 
+        )
+        self.pdfCanvas.drawString( 
+            self.width - (30*mm) - (35*mm) - (40*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.space,  
+            boletoDados.format_nosso_numero() 
+        )
+        self.pdfCanvas.drawString( 
+            self.width - (30*mm) - (35*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.space,  
+            boletoDados.numero_documento 
+        )
+        self.pdfCanvas.drawString( 
+            self.width - (30*mm) + self.space, 
+            (((linhaInicial + 1)*self.heightLine)) + self.space, 
+            boletoDados.data_documento.strftime('%d/%m/%Y')  
+        )
+
         valorDocumento = self._formataValorParaExibir(
             boletoDados.valor_documento
         )
@@ -283,20 +317,10 @@ class BoletoPDF:
         self.pdfCanvas.drawString( 
             0 + self.space, 
             (((linhaInicial + 0)*self.heightLine)) + self.space, 
-            boletoDados.sacado[0] 
+            boletoDados.cedente_endereco
         )
         self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) - (40*mm) + self.space, 
-            (((linhaInicial + 0)*self.heightLine)) + self.space,  
-            boletoDados.format_nosso_numero() 
-        )
-        self.pdfCanvas.drawString( 
-            self.width - (35*mm) - (30*mm) + self.space, 
-            (((linhaInicial + 0)*self.heightLine)) + self.space,  
-            boletoDados.numero_documento 
-        )
-        self.pdfCanvas.drawString( 
-            self.width - (35*mm) + self.space, 
+            self.width - (30*mm) + self.space, 
             (((linhaInicial + 0)*self.heightLine)) + self.space, 
             valorDocumento 
         )
@@ -306,7 +330,7 @@ class BoletoPDF:
         for i in range(len(demonstrativo)):
             self.pdfCanvas.drawString( 
                 2*self.space, 
-                (-3*cm+((linhaInicial - 1)*self.heightLine)) - (i * heighFont), 
+                (-3*cm+((linhaInicial + 0)*self.heightLine)) - (i * heighFont), 
                 demonstrativo[i] 
             )
 
@@ -314,7 +338,7 @@ class BoletoPDF:
 
         self.pdfCanvas.restoreState();
 
-        return (self.width, ((linhaInicial+2)*self.heightLine));
+        return (self.width, ((linhaInicial+3)*self.heightLine));
 
     def drawHorizontalCorteLine(self, x, y, width ):
         self.pdfCanvas.saveState();
@@ -659,7 +683,7 @@ class BoletoPDF:
             y + 2*self.space, 
             boletoDados.codigo_dv_banco 
         )
-        self.pdfCanvas.setFont('Helvetica-Bold', 10 )
+        self.pdfCanvas.setFont('Helvetica-Bold', 11.5 )
         self.pdfCanvas.drawRightString(
             self.width, 
             y + 2*self.space, 
